@@ -37,7 +37,12 @@ from datamodel_code_generator.model.base import (
 from datamodel_code_generator.model.enum import Enum
 from datamodel_code_generator.parser import DefaultPutDict, LiteralType
 from datamodel_code_generator.reference import ModelResolver, Reference
-from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes
+from datamodel_code_generator.types import (
+    DataType,
+    DataTypeManager,
+    Modular,
+    StrictTypes,
+)
 
 escape_characters = str.maketrans(
     {
@@ -302,12 +307,14 @@ class Parser(ABC):
         use_non_positive_negative_number_constrained_types: bool = False,
         original_field_name_delimiter: Optional[str] = None,
         use_double_quotes: bool = False,
+        use_union_operator: bool = False,
     ):
         self.data_type_manager: DataTypeManager = data_type_manager_type(
-            target_python_version,
-            use_standard_collections,
-            use_generic_container_types,
-            strict_types,
+            python_version=target_python_version,
+            use_standard_collections=use_standard_collections,
+            use_generic_container_types=use_generic_container_types,
+            strict_types=strict_types,
+            use_union_operator=use_union_operator,
         )
         self.data_model_type: Type[DataModel] = data_model_type
         self.data_model_root_type: Type[DataModel] = data_model_root_type
@@ -337,6 +344,7 @@ class Parser(ABC):
         self.use_subclass_enum: bool = use_subclass_enum
         self.strict_nullable: bool = strict_nullable
         self.use_generic_container_types: bool = use_generic_container_types
+        self.use_union_operator: bool = use_union_operator
         self.enable_faux_immutability: bool = enable_faux_immutability
         self.custom_class_name_generator: Optional[
             Callable[[str], str]
@@ -688,6 +696,34 @@ class Parser(ABC):
                                 )
                                 if enum_member:
                                     model_field.default = enum_member
+                                    enum_member_enum = enum_member.enum
+                                    if enum_member_enum in models:
+                                        continue
+                                    scoped_model_resolver.get(enum_member_enum.path)
+                                    if isinstance(enum_member_enum, Modular):
+                                        enum_member_enum_name = f'{enum_member_enum.module_name}.{enum_member.enum.name}'
+                                    else:
+                                        enum_member_enum_name = enum_member.enum.name
+                                    from_, import_ = full_path = relative(
+                                        model.module_name, enum_member_enum_name
+                                    )
+
+                                    alias = scoped_model_resolver.add(
+                                        full_path, import_
+                                    ).name
+
+                                    name = data_type.reference.short_name
+                                    if from_ and import_ and alias != name:
+                                        enum_member.alias = f'{alias}.{name}'
+
+                                    if init:
+                                        from_ += "."
+                                    imports.append(
+                                        Import(
+                                            from_=from_, import_=import_, alias=alias
+                                        )
+                                    )
+
             if with_import:
                 result += [str(self.imports), str(imports), '\n']
 
