@@ -333,6 +333,7 @@ class JsonSchemaParser(Parser):
         use_non_positive_negative_number_constrained_types: bool = False,
         original_field_name_delimiter: Optional[str] = None,
         use_double_quotes: bool = False,
+        use_union_operator: bool = False,
     ):
         super().__init__(
             source=source,
@@ -380,6 +381,7 @@ class JsonSchemaParser(Parser):
             use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
             original_field_name_delimiter=original_field_name_delimiter,
             use_double_quotes=use_double_quotes,
+            use_union_operator=use_union_operator,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
@@ -430,7 +432,9 @@ class JsonSchemaParser(Parser):
         if isinstance(obj.type, list):
             return self.data_type(
                 data_types=[
-                    _get_data_type(t, 'default') for t in obj.type if t != 'null'
+                    _get_data_type(t, obj.format or 'default')
+                    for t in obj.type
+                    if t != 'null'
                 ],
                 is_optional='null' in obj.type,
             )
